
This package contains example code related to the completeness
measure described in

    Dickscheid, Timo / Schindler, Falko / Foerstner, Wolfgang:
    Coding Images with Local Features
    In: International Journal of Computer Vision, 2010.
    
In particular, the code allows to compute the entropy density p_H for 
an image via

    H = entropy(imread('cameraman.tif'));
    imagesc(H(33 : end - 32, 33 : end - 32));

Note that computing the entropy takes quite a time. 
We assume that you are able to generate a file of detected features
in the format described on the "affine covariant features" website
http://www.robots.ox.ac.uk/~vgg/research/affine/detectors.html
For example, you can use the detector binaries provided on this site 
to generate such files.

For a given file containing features in this format (say 
'cameraman.haraf'), you can compute the feature coding density p_C 
via

    F = coding('cameraman.tif','cameraman.haraf');
    
The distance between the feature coding and the reference p_H,
using the Hellinger's distance, is finally obtained by
    
    d = distance(F,H);

You can just as well compute distances between feature coding densities
directly, without using the reference. We used this for the Euclidean 
embeddings described in the paper. Then you do something like this:

    C1 = coding('cameraman.tif', 'sfop0.dat');
    C2 = coding('cameraman.tif', 'sfop90.dat');
    distance(C1, C2)

    
If you use the software, we would appreciate if you cite the publication.
Use this bibtex entry:

     @article{dickscheid*10:coding,
       author = {Dickscheid, T. and Schindler, F. and F\"{o}rstner, W.}, 
       title = {Coding Images with Local Features},
       journal = {International Journal of Computer Vision}, 
        year = {2010}, 
        doi = {10.1007/s11263-010-0340-z}, 
    } 
    
---
Falko Schindler and Timo Dickscheid
Software by falko.schindler@uni-bonn.de
June 2010