function D = distance(M1, M2)
% DISTANCE computes the Hellinger's distance D between two given maps M1
% and M2.
%
% See also: coding, entropy
%
%
% For details about the method, refer to
% @article{dickscheid*10:coding,
%   author = {Dickscheid, T. and Schindler, F. and F\"{o}rstner, W.}, 
%   title = {Coding Images with Local Features},
%   journal = {International Journal of Computer Vision}, 
%    year = {2010}, 
%    doi = {10.1007/s11263-010-0340-z}, 
% } 
% If you use this software for your research, we would be glad if you 
% cite our work.
%
% Licence:
%   For internal use only.
%
% Author:
%   Falko Schindler (falko.schindler@uni-bonn.de)
%   Department of Photogrammetry
%   Institute of Geodesy and Geoinformation
%   University of Bonn
%   Bonn, Germany
%
% Example:
%   C1 = coding('cameraman.tif', 'sfop0.dat');
%   C2 = coding('cameraman.tif', 'sfop90.dat');
%   distance(C1, C2)
%
% Copyright 2009-2010

%% crop and normalize
b = 32;
M1 = M1(b + 1 : end - b, b + 1 : end - b);
if sum(M1(:)), M1 = M1 ./ sum(M1(:)); end
M2 = M2(b + 1 : end - b, b + 1 : end - b);
if sum(M2(:)), M2 = M2 ./ sum(M2(:)); end

%% compute Hellinger's distance
D = sqrt(1 / 2 * sum((sqrt(M1(:)) - sqrt(M2(:))).^2));
