function [feats, factors] = loadFeatures(files)
% LOADFEATURES loads keypoints from an ASCII file into an array FEATS.
% See http://www.robots.ox.ac.uk/~vgg/research/affine/detectors.html for a
% desciption of such a keypoint file.
%
% For details about the method, refer to
% @article{dickscheid*10:coding,
%   author = {Dickscheid, T. and Schindler, F. and F\"{o}rstner, W.}, 
%   title = {Coding Images with Local Features},
%   journal = {International Journal of Computer Vision}, 
%    year = {2010}, 
%    doi = {10.1007/s11263-010-0340-z}, 
% } 
% If you use this software for your research, we would be glad if you 
% cite our work.
%
%
% See also: showFeatures
%
% Licence:
%   For internal use only.
%
% Author:
%   Falko Schindler (falko.schindler@uni-bonn.de)
%   Department of Photogrammetry
%   Institute of Geodesy and Geoinformation
%   University of Bonn
%   Bonn, Germany
%
% Example:
%   [feats, factors] = loadFeatures('sfop.dat');
%
% Copyright 2009-2010

%% initialize
feats = zeros(0, 5);
factors = zeros(0, 1);
nb = 0;

%% read files
if ischar(files), files = {files}; end
for f = 1 : numel(files)
    fid = fopen(files{f}, 'r');
    dim = fscanf(fid, '%f', 1);
    fileFromTimo = dim == -42;
    if dim == 1, dim = 0; end
    if ~fscanf(fid, '%d', 1), return; end;
    if fileFromTimo
        feat = fscanf(fid, '%f', [6      , inf])';
        factors = [factors; feat(:, 6) + 1]; %#ok<AGROW>
    else
        feat = fscanf(fid, '%f', [5 + dim, inf])';
        factors = [factors; ones(size(feat, 1), 1)]; %#ok<AGROW>
    end
    fclose(fid);
    feats = [feats; feat(:, 1 : 5)]; %#ok<AGROW>
    nb = nb + size(feat, 1);
end
